@@ -1,6 +1,3 @@
-# -*- coding: utf-8 -*-
-from __future__ import absolute_import, unicode_literals
-
 from case import Mock
 
 from kombu.asynchronous.aws import connect_sqs
