@@ -1,5 +1,3 @@
-from __future__ import absolute_import, unicode_literals
-
 import pickle
 import pytest
 import sys
@@ -97,7 +95,7 @@ class test_Producer:
         assert json.loads(zlib.decompress(m).decode('utf-8')) == message
 
     def test_prepare_custom_content_type(self):
-        message = 'the quick brown fox'.encode('utf-8')
+        message = b'the quick brown fox'
         channel = self.connection.channel()
         p = Producer(channel, self.exchange, serializer='json')
         m, ctype, cencoding = p._prepare(message, content_type='custom')
